#!/bin/bash
#
# Copyright (c) 2010 Yahoo! Inc. All rights reserved. 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License. See accompanying LICENSE file.
#

function printUsage() {
  echo
  echo " Usage  : oozie-setup.sh <OPTIONS>"
  echo "          [-extjs EXTJS_PATH] (expanded or ZIP, to enable the Oozie webconsole)"
  echo "          [-jars JARS_PATH] (multiple JAR path separated by ':')"
  echo "          (without options does default setup, without the Oozie webconsole)"
  echo
  echo " EXTJS can be downloaded from http://www.extjs.com/learn/Ext_Version_Archives"
  echo
}

# resolve links - $0 may be a softlink
PRG="${0}"

while [ -h "${PRG}" ]; do
  ls=`ls -ld "${PRG}"`
  link=`expr "$ls" : '.*-> \(.*\)$'`
  if expr "$link" : '/.*' > /dev/null; then
    PRG="$link"
  else
    PRG=`dirname "${PRG}"`/"$link"
  fi
done

BASEDIR=`dirname ${PRG}`
BASEDIR=`cd ${BASEDIR}/..;pwd`

addExtjs=""
addJars=""
extjsHome=""
jarsPath=""
inputWar="${BASEDIR}/oozie.war"
outputWar="${BASEDIR}/oozie-server/webapps/oozie.war"
outputWarExpanded="${BASEDIR}/oozie-server/webapps/oozie"

while [ $# -gt 0 ]
do
  if [ "$1" = "-extjs" ]; then
    shift
    if [ $# -eq 0 ]; then
      echo
      echo "Missing option value, ExtJS path"
      echo
      printUsage
      exit -1
    fi
    extjsHome=$1
    addExtjs=true
  elif [ "$1" = "-jars" ]; then
    shift
    if [ $# -eq 0 ]; then
      echo
      echo "Missing option value, JARs path"
      echo
      printUsage
      exit -1
    fi
    jarsPath=$1
    addJars=true
  else
    printUsage
    exit -1
  fi
    shift
done

echo
echo "Stopping Oozie (if running)"
echo
${BASEDIR}/bin/oozie-stop.sh
echo

if [ -e "${outputWar}" ]; then
  chmod -f u+w ${outputWar}
  rm -rf ${outputWar}
fi
rm -rf ${outputWarExpanded}

if [ "${addExtjs}${addJars}" == "" ]; then
  echo
  echo "Default installation, Oozie webconsole disabled"
  echo
  cp ${inputWar} ${outputWar}
else
  OPTIONS=""
  if [ "${addExtjs}" != "" ]; then
    OPTIONS="-extjs ${extjsHome}"
  fi
  if [ "${addJars}" != "" ]; then
    OPTIONS="${OPTIONS} -jars ${jarsPath}"
  fi

  ${BASEDIR}/bin/addtowar.sh -inputwar ${inputWar} -outputwar ${outputWar} ${OPTIONS}

  if [ "$?" != "0" ]; then
    exit -1
  fi
fi

echo
echo "Oozie at ${BASEDIR} is ready to be started"
echo
